@@ -121,7 +121,7 @@ class TestAuditTemplate(base.BaseInfraOptimTest):
         _, body = self.client.list_audit_templates(limit=3)
 
         next_marker = body['audit_templates'][-1]['uuid']
-        self.assertEqual(len(body['audit_templates']), 3)
+        self.assertEqual(3, len(body['audit_templates']))
         self.assertIn(next_marker, body['next'])
 
     @test.attr(type='smoke')
@@ -137,7 +137,7 @@ class TestAuditTemplate(base.BaseInfraOptimTest):
         new_name = 'my at new name %s' % uuid.uuid4()
         new_description = 'my new at description'
         new_host_aggregate = 10
-        new_goal = 'A NEW GOAL'
+        new_goal = 'BASIC_CONSOLIDATION'
         new_extra = {'key1': 'new-value1', 'key2': 'new-value2'}
 
         patch = [{'path': '/name',
